Welcome to macrame's documentation!
===================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   source/intro.rst
   source/quick-start.rst
   gen/modules.rst

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
